
:autogenerated:

krotov.convergence module
=========================

.. currentmodule:: krotov.convergence

.. automodule:: krotov.convergence
    :members: Or, check_monotonic_error, check_monotonic_fidelity, delta_below, value_below
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        Or
        check_monotonic_error
        check_monotonic_fidelity
        delta_below
        value_below





    ``__all__``: :func:`Or <krotov.convergence.Or>`, :func:`check_monotonic_error <krotov.convergence.check_monotonic_error>`, :func:`check_monotonic_fidelity <krotov.convergence.check_monotonic_fidelity>`, :func:`delta_below <krotov.convergence.delta_below>`, :func:`value_below <krotov.convergence.value_below>`



    Reference
    ---------